from django.shortcuts import render, redirect, get_object_or_404
from .models import Shift, LoginToken, Helper
import datetime
from django.db.models import F, Count
from .forms import RegisterForm

def index(request):
    # dont show shifts starting in <60 minutes?
    # currently only sorts by date
    free_shifts = Shift.objects.annotate(reg_count=Count('shiftregistration')).filter(start_at__gt=datetime.datetime.now(),
                    room__required_helpers__gt=F('reg_count')).order_by('start_at')
    context = {'free_shifts': free_shifts}
    if request.session.get('token'):
        context['helper'] = LoginToken.objects.get(pk=request.session['token']).helper
    return render(request, 'shiftlist.html', context)

def login(request, token):
    tk = get_object_or_404(LoginToken,pk=token)
    if not tk.helper.number_validated:
        tk.helper.number_validated=True
        tk.helper.save()
    request.session['token'] = token
    return redirect('index')

def logout(request):
    del request.session['token']
    return redirect('index')

def register(request):
    # handle number already being registered(resend message?)
    if request.session.get('token'):
         return redirect('index')
    context = {}
    if request.method == 'POST':
        form = RegisterForm(request.POST)
        if not form.is_valid():
            context['form']=form
            return render(request, 'register.html', context)
        helper = Helper(name = form.cleaned_data['name'], phone=form.cleaned_data['phone'])
        helper.save()
        token = helper.send_confirmation()
        request.session['token'] = token.pk
        return render(request, 'wait_confirmation.html', {'helper':helper})
        
    context['form']=RegisterForm()
    return render(request, 'register.html', context)